@@ -1527,10 +1527,38 @@ TIMESTAMP;
 GENERATE_UUID();
 STRING;
 
+# dialect: bigquery
+STRUCT(tbl.str_col);
+STRUCT<str_col STRING>;
+
 --------------------------------------
 -- Snowflake
 --------------------------------------
 
+# dialect: snowflake
+AI_AGG('foo', 'bar');
+VARCHAR;
+
+# dialect: snowflake
+AI_AGG(null, 'bar');
+VARCHAR;
+
+# dialect: snowflake
+AI_SUMMARIZE_AGG('foo');
+VARCHAR;
+
+# dialect: snowflake
+AI_SUMMARIZE_AGG(null);
+VARCHAR;
+
+# dialect: snowflake
+AI_CLASSIFY('text', ['travel', 'cooking']);
+VARCHAR;
+
+# dialect: snowflake
+AI_CLASSIFY('text', ['travel', 'cooking'], {'output_mode': 'multi'});
+VARCHAR;
+
 # dialect: snowflake
 CHARINDEX('world', 'hello world');
 INT;
@@ -1631,6 +1659,86 @@ INT;
 LOWER(tbl.str_col);
 VARCHAR;
 
+# dialect: snowflake
+LTRIM('  hello world  ');
+VARCHAR;
+
+# dialect: snowflake
+LTRIM(tbl.str_col);
+VARCHAR;
+
+# dialect: snowflake
+LTRIM(NULL);
+VARCHAR;
+
+# dialect: snowflake
+REGEXP_LIKE('foo', 'bar');
+BOOLEAN;
+
+# dialect: snowflake
+REGEXP_LIKE(NULL, 'bar');
+BOOLEAN;
+
+# dialect: snowflake
+REGEXP_LIKE('foo', 'bar', 'baz');
+BOOLEAN;
+
+# dialect: snowflake
+REGEXP_LIKE('foo', NULL, 'baz');
+BOOLEAN;
+
+# dialect: snowflake
+REGEXP_REPLACE('hello world', 'world', 'universe');
+VARCHAR;
+
+# dialect: snowflake
+REGEXP_REPLACE('hello world', 'world', NULL);
+VARCHAR;
+
+# dialect: snowflake
+REGEXP_REPLACE('hello world', 'world', 'universe', 1, 1, 'i');
+VARCHAR;
+
+# dialect: snowflake
+REGEXP_SUBSTR('hello world', 'world');
+VARCHAR;
+
+# dialect: snowflake
+REGEXP_SUBSTR(NULL, 'world');
+VARCHAR;
+
+# dialect: snowflake
+REGEXP_SUBSTR('hello world', NULL);
+VARCHAR;
+
+# dialect: snowflake
+REGEXP_SUBSTR('hello world', 'world', 1);
+VARCHAR;
+
+# dialect: snowflake
+REGEXP_SUBSTR('hello world', 'world', 1, 1, 'e', NULL);
+VARCHAR;
+
+# dialect: snowflake
+REPEAT('hello', 3);
+VARCHAR;
+
+# dialect: snowflake
+REPEAT(tbl.str_col, 2);
+VARCHAR;
+
+# dialect: snowflake
+REPEAT('hello', NULL);
+VARCHAR;
+
+# dialect: snowflake
+REPLACE(tbl.str_col, 'old', 'new');
+VARCHAR;
+
+# dialect: snowflake
+REPLACE('hello', 'old', NULL);
+VARCHAR;
+
 # dialect: snowflake
 REVERSE('Hello, world!');
 VARCHAR;
@@ -1663,6 +1771,126 @@ BINARY;
 RIGHT(tbl.str_col, NULL);
 STRING;
 
+# dialect: snowflake
+RLIKE('foo', 'bar');
+BOOLEAN;
+
+# dialect: snowflake
+RLIKE(NULL, 'bar');
+BOOLEAN;
+
+# dialect: snowflake
+RLIKE('foo', 'bar', NULL);
+BOOLEAN;
+
+# dialect: snowflake
+RTRIM('  hello world  ');
+VARCHAR;
+
+# dialect: snowflake
+RTRIM(tbl.str_col);
+VARCHAR;
+
+# dialect: snowflake
+RTRIM(NULL);
+VARCHAR;
+
+# dialect: snowflake
+SHA1('foo');
+VARCHAR;
+
+# dialect: snowflake
+SHA1(null);
+VARCHAR;
+
+# dialect: snowflake
+SHA1_BINARY('foo');
+BINARY;
+
+# dialect: snowflake
+SHA1_BINARY(null);
+BINARY;
+
+# dialect: snowflake
+SHA1_HEX('foo');
+VARCHAR;
+
+# dialect: snowflake
+SHA1_HEX(null);
+VARCHAR;
+
+# dialect: snowflake
+SHA2('foo');
+VARCHAR;
+
+# dialect: snowflake
+SHA2(null);
+VARCHAR;
+
+# dialect: snowflake
+SHA2('foo', 256);
+VARCHAR;
+
+# dialect: snowflake
+SHA2('foo', null);
+VARCHAR;
+
+# dialect: snowflake
+SHA2_BINARY('foo');
+BINARY;
+
+# dialect: snowflake
+SHA2_BINARY(null);
+BINARY;
+
+# dialect: snowflake
+SHA2_BINARY('foo', 256);
+BINARY;
+
+# dialect: snowflake
+SHA2_BINARY('foo', null);
+BINARY;
+
+# dialect: snowflake
+SHA2_HEX('foo');
+VARCHAR;
+
+# dialect: snowflake
+SHA2_HEX(null);
+VARCHAR;
+
+# dialect: snowflake
+SHA2_HEX('foo', 256);
+VARCHAR;
+
+# dialect: snowflake
+SHA2_HEX('foo', null);
+VARCHAR;
+
+# dialect: snowflake
+SPACE(5);
+VARCHAR;
+
+# dialect: snowflake
+SPACE(tbl.int_col);
+VARCHAR;
+
+# dialect: snowflake
+SPACE(NULL);
+VARCHAR;
+
+# dialect: snowflake
+SPLIT('hello world', ' ');
+ARRAY;
+
+# dialect: snowflake
+SPLIT(tbl.str_col, ',');
+ARRAY;
+
+# dialect: snowflake
+SPLIT(NULL, ',');
+ARRAY;
+
 # dialect: snowflake
 STARTSWITH('hello world', 'hello');
 BOOLEAN;
@@ -1715,30 +1943,6 @@ VARCHAR;
 TRIM(NULL);
 VARCHAR;
 
-# dialect: snowflake
-LTRIM('  hello world  ');
-VARCHAR;
-
-# dialect: snowflake
-LTRIM(tbl.str_col);
-VARCHAR;
-
-# dialect: snowflake
-LTRIM(NULL);
-VARCHAR;
-
-# dialect: snowflake
-RTRIM('  hello world  ');
-VARCHAR;
-
-# dialect: snowflake
-RTRIM(tbl.str_col);
-VARCHAR;
-
-# dialect: snowflake
-RTRIM(NULL);
-VARCHAR;
-
 # dialect: snowflake
 UPPER('Hello, world!');
 VARCHAR;
@@ -1748,24 +1952,73 @@ UPPER(tbl.str_col);
 VARCHAR;
 
 # dialect: snowflake
-REPLACE(tbl.str_col, 'old', 'new');
+UUID_STRING();
 VARCHAR;
 
 # dialect: snowflake
-REPLACE('hello', 'old', NULL);
+UUID_STRING('foo', 'bar');
 VARCHAR;
 
 # dialect: snowflake
-SPACE(5);
+UUID_STRING(null, null);
 VARCHAR;
 
 # dialect: snowflake
-SPACE(tbl.int_col);
+MD5(tbl.str_col);
 VARCHAR;
 
 # dialect: snowflake
-SPACE(NULL);
+MD5_HEX(tbl.str_col);
 VARCHAR;
+
+# dialect: snowflake
+MD5_BINARY(tbl.str_col);
+BINARY;
+
+# dialect: snowflake
+MD5_NUMBER_LOWER64(tbl.str_col);
+BIGINT;
+
+# dialect: snowflake
+MD5_NUMBER_UPPER64(tbl.str_col);
+BIGINT;
+
+# dialect: snowflake
+'Hello' NOT ILIKE 'h%';
+BOOLEAN;
+
+# dialect: snowflake
+'Hello' ILIKE 'h_llo';
+BOOLEAN;
+
+# dialect: snowflake
+tbl.str_col NOT ILIKE '%x%';
+BOOLEAN;
+
+# dialect: snowflake
+'Hello' NOT LIKE 'H%';
+BOOLEAN;
+
+# dialect: snowflake
+'Hello' LIKE 'H_llo';
+BOOLEAN;
+
+# dialect: snowflake
+tbl.str_col NOT LIKE '%e%';
+BOOLEAN;
+
+# dialect: snowflake
+tbl.str_col LIKE ALL ('H%', '%o');
+BOOLEAN;
+
+# dialect: snowflake
+tbl.str_col LIKE ANY ('H%', '%o');
+BOOLEAN;
+
+# dialect: snowflake
+tbl.str_col ILIKE ANY ('h%', '%x');
+BOOLEAN;
+
 --------------------------------------
 -- T-SQL
 --------------------------------------
